tsseg.algorithms.autoplait package
==================================

Automatic mining of co-evolving time sequences by discovering regimes (recurring
dynamical patterns modelled as HMMs) and segmenting the series accordingly. Uses
MDL principle.

| **Type:** state detection
| **Supervision:** fully unsupervised (MDL)
| **Scope:** multivariate
| **Requires:** compiled C binary

**Implementation:** Wraps original C code by Yasuko Matsubara (Kumamoto University).
*Origin: wrapper around original C code.* No explicit licence.

**Reference:** Matsubara, Sakurai & Faloutsos (2014), SIGMOD.

Submodules
----------

tsseg.algorithms.autoplait.autoplait\_c module
----------------------------------------------

.. automodule:: tsseg.algorithms.autoplait.autoplait_c
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.autoplait.autoplait\_python module
---------------------------------------------------

.. automodule:: tsseg.algorithms.autoplait.autoplait_python
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.autoplait.detector module
------------------------------------------

.. automodule:: tsseg.algorithms.autoplait.detector
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.autoplait.detector\_python module
--------------------------------------------------

.. automodule:: tsseg.algorithms.autoplait.detector_python
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.autoplait
   :members:
   :show-inheritance:
   :undoc-members:
